@@ -1,21 +1,29 @@
 package Fey;
+BEGIN {
+  $Fey::VERSION = '0.35';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.34';
-
 use Moose 0.90 ();
 
-
 1;
 
-__END__
+# ABSTRACT: Better SQL Generation Through Perl
+
+
+
+=pod
 
 =head1 NAME
 
 Fey - Better SQL Generation Through Perl
 
+=head1 VERSION
+
+version 0.35
+
 =head1 SYNOPSIS
 
   use Fey::Literal::Function;
@@ -386,10 +394,6 @@ crazy". This project is certainly that.
 
 Yes, I'm a nerd, I know.
 
-=head1 AUTHOR
-
-Dave Rolsky, <autarch@urth.org>
-
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-fey@rt.cpan.org>,
@@ -397,12 +401,20 @@ or through the web interface at L<http://rt.cpan.org>.  I will be
 notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
+  Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. The full text of the license
-can be found in the LICENSE file included with this module.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
