@@ -1,29 +1,27 @@
 package Fey::Literal::String;
+BEGIN {
+  $Fey::Literal::String::VERSION = '0.35';
+}
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
-our $VERSION = '0.34';
-
-use Fey::Types;
+use Fey::Types qw( Str );
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
 use MooseX::StrictConstructor;
 
-with 'Fey::Role::Comparable',
-     'Fey::Role::Selectable',
-     'Fey::Role::IsLiteral';
+with 'Fey::Role::Comparable', 'Fey::Role::Selectable', 'Fey::Role::IsLiteral';
 
-has 'string' =>
-    ( is       => 'ro',
-      isa      => 'Str',
-      required => 1,
-    );
+has 'string' => (
+    is       => 'ro',
+    isa      => Str,
+    required => 1,
+);
 
-
-sub BUILDARGS
-{
+sub BUILDARGS {
     my $class = shift;
 
     return { string => shift };
@@ -35,18 +33,24 @@ sub sql_with_alias { goto &sql }
 
 sub sql_or_alias { goto &sql }
 
-no Moose;
-
 __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: Represents a literal string in a SQL statement
+
+
+
+=pod
 
 =head1 NAME
 
 Fey::Literal::String - Represents a literal string in a SQL statement
 
+=head1 VERSION
+
+version 0.35
+
 =head1 SYNOPSIS
 
   my $string = Fey::Literal::String->new($string)
@@ -89,19 +93,24 @@ Returns the appropriate SQL snippet.
 This class does the C<Fey::Role::Selectable> and
 C<Fey::Role::Comparable> roles.
 
-=head1 AUTHOR
-
-Dave Rolsky, <autarch@urth.org>
-
 =head1 BUGS
 
 See L<Fey> for details on how to report bugs.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
+  Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
