@@ -1,11 +1,13 @@
 package Fey::Literal::Term;
+BEGIN {
+  $Fey::Literal::Term::VERSION = '0.35';
+}
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
-our $VERSION = '0.34';
-
-use Fey::Types;
+use Fey::Types qw( Bool LiteralTermArg );
 
 use Carp qw( croak );
 use Moose;
@@ -13,43 +15,41 @@ use MooseX::SemiAffordanceAccessor;
 use MooseX::StrictConstructor;
 
 with 'Fey::Role::Comparable', 'Fey::Role::Selectable',
-     'Fey::Role::Orderable', 'Fey::Role::Groupable',
-     'Fey::Role::IsLiteral';
+    'Fey::Role::Orderable', 'Fey::Role::Groupable',
+    'Fey::Role::IsLiteral';
 
-has 'term' =>
-    ( is       => 'ro',
-      isa      => 'Fey::Types::LiteralTermArg',
-      required => 1,
-      coerce   => 1,
-    );
+has 'term' => (
+    is       => 'ro',
+    isa      => LiteralTermArg,
+    required => 1,
+    coerce   => 1,
+);
 
-has can_have_alias =>
-    ( is       => 'rw',
-      isa      => 'Bool',
-      default  => 1,
-    );
+has can_have_alias => (
+    is      => 'rw',
+    isa     => Bool,
+    default => 1,
+);
 
-with 'Fey::Role::HasAliasName' =>
-    { generated_alias_prefix => 'TERM' };
+with 'Fey::Role::HasAliasName' => { generated_alias_prefix => 'TERM' };
 
-sub BUILDARGS
-{
+sub BUILDARGS {
     my $class = shift;
 
-    return { term => [ @_ ] };
+    return { term => [@_] };
 }
 
-sub sql
-{
-    my ($self, $dbh) = @_;
+sub sql {
+    my ( $self, $dbh ) = @_;
 
-    return
-        join( '',
-              map { blessed($_) && $_->can('sql_or_alias')
-                    ? $_->sql_or_alias($dbh)
-                    : $_ }
-              @{ $self->term() }
-            );
+    return join(
+        '',
+        map {
+            blessed($_) && $_->can('sql_or_alias')
+                ? $_->sql_or_alias($dbh)
+                : $_
+            } @{ $self->term() }
+    );
 }
 
 # XXX - this bit of wackness is necessary because MX::Role::Parameterized
@@ -61,37 +61,43 @@ sub sql
     my $method = $meta->remove_method('sql_with_alias');
     $meta->add_method( _han_sql_with_alias => $method );
 
-    my $sql_with_alias = sub
-    {
+    my $sql_with_alias = sub {
         my $self = shift;
         my $dbh  = shift;
 
-        return $self->can_have_alias() ? $self->_han_sql_with_alias($dbh) : $self->sql($dbh);
+        return $self->can_have_alias()
+            ? $self->_han_sql_with_alias($dbh)
+            : $self->sql($dbh);
     };
 
     $meta->add_method( sql_with_alias => $sql_with_alias );
 }
 
-before 'set_alias_name' => sub
-{
+before 'set_alias_name' => sub {
     my $self = shift;
 
     croak 'This term cannot have an alias'
         unless $self->can_have_alias();
 };
 
-no Moose;
-
 __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: Represents a literal term in a SQL statement
+
+
+
+=pod
 
 =head1 NAME
 
 Fey::Literal::Term - Represents a literal term in a SQL statement
 
+=head1 VERSION
+
+version 0.35
+
 =head1 SYNOPSIS
 
   my $term = Fey::Literal::Term->new(@anything)
@@ -146,7 +152,7 @@ Returns the array reference of fragments passed to the constructor.
 
 =head2 $term->set_can_have_alias()
 
-If this attribute is explicitly set to a true value, then then the
+If this attribute is explicitly set to a false value, then then the
 SQL-generating methods below will never include an alias.
 
 =head2 $term->id()
@@ -181,19 +187,24 @@ Of course, the contents of a given term may not really allow for any
 of these things, but having this class do these roles means you can
 freely use a term object in any part of a SQL snippet.
 
-=head1 AUTHOR
-
-Dave Rolsky, <autarch@urth.org>
-
 =head1 BUGS
 
 See L<Fey> for details on how to report bugs.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
+  Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
