@@ -1,29 +1,36 @@
 package Fey::Role::IsLiteral;
+BEGIN {
+  $Fey::Role::IsLiteral::VERSION = '0.35';
+}
 
 use strict;
 use warnings;
-
-our $VERSION = '0.34';
+use namespace::autoclean;
 
 use Moose::Role;
 
 requires 'sql';
 
-sub id
-{
+sub id {
     return $_[0]->sql('Fey::FakeDBI');
 }
 
-no Moose::Role;
-
 1;
 
-__END__
+# ABSTRACT: A role for things that are literals
+
+
+
+=pod
 
 =head1 NAME
 
 Fey::Role::IsLiteral - A role for things that are literals
 
+=head1 VERSION
+
+version 0.35
+
 =head1 SYNOPSIS
 
   use Moose;
@@ -35,19 +42,24 @@ Fey::Role::IsLiteral - A role for things that are literals
 This role provides an C<id()> method that simply calls C<<
 $object->sql('Fey::FakeDBI') >>.
 
-=head1 AUTHOR
-
-Dave Rolsky, <autarch@urth.org>
-
 =head1 BUGS
 
 See L<Fey> for details on how to report bugs.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
+  Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
