@@ -1,44 +1,53 @@
 package Fey::Role::SQL::HasBindParams;
+BEGIN {
+  $Fey::Role::SQL::HasBindParams::VERSION = '0.35';
+}
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
-our $VERSION = '0.34';
+use Fey::Types qw( ArrayRef Bool );
 
 use Moose::Role;
 
-has '_bind_params' =>
-    ( traits   => [ 'Array' ],
-      is       => 'ro',
-      isa      => 'ArrayRef',
-      default  => sub { [] },
-      handles  => { _add_bind_param => 'push' },
-      init_arg => undef,
-    );
+has '_bind_params' => (
+    traits   => ['Array'],
+    is       => 'ro',
+    isa      => ArrayRef,
+    default  => sub { [] },
+    handles  => { _add_bind_param => 'push' },
+    init_arg => undef,
+);
 
-has 'auto_placeholders' =>
-    ( is      => 'ro',
-      isa     => 'Bool',
-      default => 1,
-    );
+has 'auto_placeholders' => (
+    is      => 'ro',
+    isa     => Bool,
+    default => 1,
+);
 
 # This needs to be a method and not a delegated method so it can be excluded
 # by classes which need to exclude it.
-sub bind_params
-{
+sub bind_params {
     return @{ $_[0]->_bind_params() };
 }
 
-no Moose::Role;
-
 1;
 
-__END__
+# ABSTRACT: A role for queries which can have bind parameters
+
+
+
+=pod
 
 =head1 NAME
 
 Fey::Role::SQL::HasBindParams - A role for queries which can have bind parameters
 
+=head1 VERSION
+
+version 0.35
+
 =head1 SYNOPSIS
 
   use Moose;
@@ -63,19 +72,24 @@ Returns the bind params associated with the query.
 This attribute determines whether values are automatically turned into
 placeholders and stored as bind parameters.
 
-=head1 AUTHOR
-
-Dave Rolsky, <autarch@urth.org>
-
 =head1 BUGS
 
 See L<Fey> for details on how to report bugs.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
+  Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
