@@ -1,9 +1,11 @@
 package Fey::Role::SQL::HasWhereClause;
+BEGIN {
+  $Fey::Role::SQL::HasWhereClause::VERSION = '0.35';
+}
 
 use strict;
 use warnings;
-
-our $VERSION = '0.34';
+use namespace::autoclean;
 
 use Fey::Exceptions qw( param_error );
 
@@ -11,25 +13,25 @@ use Fey::SQL::Fragment::Where::Boolean;
 use Fey::SQL::Fragment::Where::Comparison;
 use Fey::SQL::Fragment::Where::SubgroupStart;
 use Fey::SQL::Fragment::Where::SubgroupEnd;
+use Fey::Types qw( ArrayRef );
 
 use Moose::Role;
 
-has '_where' =>
-    ( traits   => [ 'Array' ],
-      is       => 'bare',
-      isa      => 'ArrayRef',
-      default  => sub { [] },
-      handles  => { _add_where_element  => 'push',
-                    _has_where_elements => 'count',
-                    _last_where_element => [ 'get', -1 ],
-                    _where              => 'elements',
-                  },
-      init_arg => undef,
-    );
+has '_where' => (
+    traits  => ['Array'],
+    is      => 'bare',
+    isa     => ArrayRef,
+    default => sub { [] },
+    handles => {
+        _add_where_element  => 'push',
+        _has_where_elements => 'count',
+        _last_where_element => [ 'get', -1 ],
+        _where              => 'elements',
+    },
+    init_arg => undef,
+);
 
-
-sub where
-{
+sub where {
     my $self = shift;
 
     $self->_condition( 'where', @_ );
@@ -38,33 +40,30 @@ sub where
 }
 
 # Just some sugar
-sub and
-{
+sub and {
     my $self = shift;
 
     return $self->where(@_);
 }
 
 {
-    my %dispatch = ( 'and' => '_and',
-                     'or'  => '_or',
-                     '('   => '_subgroup_start',
-                     ')'   => '_subgroup_end',
-                   );
-    sub _condition
-    {
+    my %dispatch = (
+        'and' => '_and',
+        'or'  => '_or',
+        '('   => '_subgroup_start',
+        ')'   => '_subgroup_end',
+    );
+
+    sub _condition {
         my $self = shift;
         my $key  = shift;
 
-        if ( @_ == 1 )
-        {
-            if ( my $meth = $dispatch{ lc $_[0] } )
-            {
+        if ( @_ == 1 ) {
+            if ( my $meth = $dispatch{ lc $_[0] } ) {
                 $self->$meth($key);
                 return;
             }
-            else
-            {
+            else {
                 param_error
                     qq|Cannot pass one argument to $key() unless it is one of "and", "or", "(", or ")".|;
             }
@@ -73,13 +72,15 @@ sub and
         $self->_add_and_if_needed($key);
 
         my $add_method = '_add_' . $key . '_element';
-        $self->$add_method
-            ( Fey::SQL::Fragment::Where::Comparison->new( $self->auto_placeholders(), @_ ) );
+        $self->$add_method(
+            Fey::SQL::Fragment::Where::Comparison->new(
+                $self->auto_placeholders(), @_
+            )
+        );
     }
 }
 
-sub _add_and_if_needed
-{
+sub _add_and_if_needed {
     my $self = shift;
     my $key  = shift;
 
@@ -88,7 +89,7 @@ sub _add_and_if_needed
     return unless $self->$has_method();
 
     my $last_method = '_last_' . $key . '_element';
-    my $last = $self->$last_method();
+    my $last        = $self->$last_method();
 
     return if $last->isa('Fey::SQL::Fragment::Where::Boolean');
     return if $last->isa('Fey::SQL::Fragment::Where::SubgroupStart');
@@ -96,58 +97,51 @@ sub _add_and_if_needed
     $self->_and($key);
 }
 
-sub _and
-{
+sub _and {
     my $self = shift;
     my $key  = shift;
 
     my $add_method = '_add_' . $key . '_element';
-    $self->$add_method
-        ( Fey::SQL::Fragment::Where::Boolean->new( comparison => 'AND' ) );
+    $self->$add_method(
+        Fey::SQL::Fragment::Where::Boolean->new( comparison => 'AND' ) );
 
     return $self;
 }
 
-sub _or
-{
+sub _or {
     my $self = shift;
     my $key  = shift;
 
     my $add_method = '_add_' . $key . '_element';
-    $self->$add_method
-        ( Fey::SQL::Fragment::Where::Boolean->new( comparison => 'OR' ) );
+    $self->$add_method(
+        Fey::SQL::Fragment::Where::Boolean->new( comparison => 'OR' ) );
 
     return $self;
 }
 
-sub _subgroup_start
-{
+sub _subgroup_start {
     my $self = shift;
     my $key  = shift;
 
     $self->_add_and_if_needed($key);
 
     my $add_method = '_add_' . $key . '_element';
-    $self->$add_method
-        ( Fey::SQL::Fragment::Where::SubgroupStart->new() );
+    $self->$add_method( Fey::SQL::Fragment::Where::SubgroupStart->new() );
 
     return $self;
 }
 
-sub _subgroup_end
-{
+sub _subgroup_end {
     my $self = shift;
     my $key  = shift;
 
     my $add_method = '_add_' . $key . '_element';
-    $self->$add_method
-        ( Fey::SQL::Fragment::Where::SubgroupEnd->new() );
+    $self->$add_method( Fey::SQL::Fragment::Where::SubgroupEnd->new() );
 
     return $self;
 }
 
-sub where_clause
-{
+sub where_clause {
     my $self       = shift;
     my $dbh        = shift;
     my $skip_where = shift;
@@ -158,35 +152,40 @@ sub where_clause
     $sql = 'WHERE '
         unless $skip_where;
 
-    return ( $sql
-             . ( join ' ',
-                 map { $_->sql($dbh) }
-                 $self->_where()
-               )
-           );
+    return (
+        $sql
+            . (
+            join ' ',
+            map { $_->sql($dbh) } $self->_where()
+            )
+    );
 }
 
-sub bind_params
-{
+sub bind_params {
     my $self = shift;
 
-    return
-        ( map { $_->bind_params() }
-          grep { $_->can('bind_params') }
-          $self->_where()
-        );
+    return (
+        map  { $_->bind_params() }
+        grep { $_->can('bind_params') } $self->_where()
+    );
 }
 
-no Moose::Role;
-
 1;
 
-__END__
+# ABSTRACT: A role for queries which can include a WHERE clause
+
+
+
+=pod
 
 =head1 NAME
 
 Fey::Role::SQL::HasWhereClause - A role for queries which can include a WHERE clause
 
+=head1 VERSION
+
+version 0.35
+
 =head1 SYNOPSIS
 
   use Moose;
@@ -202,33 +201,41 @@ C<WHERE> clause.
 
 This role provides the following methods:
 
-=head2 $query->where()
+=head2 $query->where(...)
 
 See the L<Fey::SQL section on WHERE Clauses|Fey::SQL/WHERE Clauses>
 for more details.
 
-=head2 $query->and()
+=head2 $query->and(...)
 
 See the L<Fey::SQL section on WHERE Clauses|Fey::SQL/WHERE Clauses>
 for more details.
 
-=head2 $query->where_clause()
+=head2 $query->where_clause( $dbh, $skip_where )
 
-Returns the C<WHERE> clause portion of the SQL statement as a string.
-
-=head1 AUTHOR
-
-Dave Rolsky, <autarch@urth.org>
+Returns the C<WHERE> clause portion of the SQL statement as a string. The
+first argument, a database handle, is required. If the second argument is
+true, the string returned will not start with "WHERE", it will simply start
+with the where clause conditions.
 
 =head1 BUGS
 
 See L<Fey> for details on how to report bugs.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
+  Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
