@@ -1,24 +1,32 @@
 package Fey::Role::SQL::ReturnsData;
+BEGIN {
+  $Fey::Role::SQL::ReturnsData::VERSION = '0.35';
+}
 
 use strict;
 use warnings;
-
-our $VERSION = '0.34';
+use namespace::autoclean;
 
 use Moose::Role;
 
 # This doesn't actually work with Fey::Role::SetOperation in the mix.
 #requires 'select_clause_elements';
 
-no Moose::Role;
-
 1;
 
-__END__
+# ABSTRACT: A role for SQL queries which return data (SELECT, UNION, etc)
+
+
+
+=pod
 
 =head1 NAME
 
-Fey::Role::ReturnsData - A role for SQL queries which return data (SELECT, UNION, etc)
+Fey::Role::SQL::ReturnsData - A role for SQL queries which return data (SELECT, UNION, etc)
+
+=head1 VERSION
+
+version 0.35
 
 =head1 SYNOPSIS
 
@@ -37,19 +45,24 @@ This role provides no methods.
 
 Returns true.
 
-=head1 AUTHOR
-
-Dave Rolsky, <autarch@urth.org>
-
 =head1 BUGS
 
 See L<Fey> for details on how to report bugs.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
+  Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
