@@ -1,25 +1,32 @@
 package Fey::Role::Selectable;
+BEGIN {
+  $Fey::Role::Selectable::VERSION = '0.35';
+}
 
 use strict;
 use warnings;
-
-our $VERSION = '0.34';
+use namespace::autoclean;
 
 use Moose::Role;
 
-
-sub is_selectable { 1 }
-
-no Moose::Role;
+sub is_selectable {1}
 
 1;
 
-__END__
+# ABSTRACT: A role for things that can go in a SELECT clause
+
+
+
+=pod
 
 =head1 NAME
 
 Fey::Role::Selectable - A role for things that can go in a SELECT clause
 
+=head1 VERSION
+
+version 0.35
+
 =head1 SYNOPSIS
 
   use Moose;
@@ -39,19 +46,24 @@ This role provides the following methods:
 
 Returns true.
 
-=head1 AUTHOR
-
-Dave Rolsky, <autarch@urth.org>
-
 =head1 BUGS
 
 See L<Fey> for details on how to report bugs.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
+  Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
