@@ -1,24 +1,32 @@
 package Fey::Role::TableLike;
+BEGIN {
+  $Fey::Role::TableLike::VERSION = '0.35';
+}
 
 use strict;
 use warnings;
-
-our $VERSION = '0.34';
+use namespace::autoclean;
 
 use Moose::Role;
 
 with 'Fey::Role::Joinable';
 
-no Moose::Role;
-
 1;
 
-__END__
+# ABSTRACT: A role for things that are like a table
+
+
+
+=pod
 
 =head1 NAME
 
 Fey::Role::TableLike - A role for things that are like a table
 
+=head1 VERSION
+
+version 0.35
+
 =head1 SYNOPSIS
 
   use Moose;
@@ -30,19 +38,24 @@ Fey::Role::TableLike - A role for things that are like a table
 This role has no methods or attributes of its own. It does consume the
 L<Fey::Role::Joinable> role.
 
-=head1 AUTHOR
-
-Dave Rolsky, <autarch@urth.org>
-
 =head1 BUGS
 
 See L<Fey> for details on how to report bugs.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
+  Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
