@@ -1,9 +1,11 @@
 package Fey::SQL::Except;
+BEGIN {
+  $Fey::SQL::Except::VERSION = '0.35';
+}
 
 use strict;
 use warnings;
-
-our $VERSION = '0.34';
+use namespace::autoclean;
 
 use Moose;
 
@@ -11,14 +13,22 @@ with 'Fey::Role::SetOperation' => { keyword => 'EXCEPT' };
 
 with 'Fey::Role::SQL::Cloneable';
 
-no Moose;
-
 1;
 
+# ABSTRACT: Represents an EXCEPT operation
+
+
+__END__
+=pod
+
 =head1 NAME
 
 Fey::SQL::Except - Represents an EXCEPT operation
 
+=head1 VERSION
+
+version 0.35
+
 =head1 SYNOPSIS
 
   my $except = Fey::SQL->new_except;
@@ -53,19 +63,21 @@ See L<Fey::Role::SetOperation> for all methods.
 
 =back
 
-=head1 AUTHOR
-
-Hans Dieter Pearcey, <hdp.cpan.fey@weftsoar.net>
-
 =head1 BUGS
 
 See L<Fey> for details on how to report bugs.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2009 Dave Rolsky, All Rights Reserved.
+  Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
