@@ -1,9 +1,11 @@
 package Fey::SQL::Where;
+BEGIN {
+  $Fey::SQL::Where::VERSION = '0.35';
+}
 
 use strict;
 use warnings;
-
-our $VERSION = '0.34';
+use namespace::autoclean;
 
 use Fey::Types;
 
@@ -17,18 +19,24 @@ with 'Fey::Role::SQL::HasBindParams' => { excludes => 'bind_params' };
 
 with 'Fey::Role::SQL::Cloneable';
 
-no Moose;
-
 __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: Represents a "stand-alone" WHERE clause
+
+
+
+=pod
 
 =head1 NAME
 
 Fey::SQL::Where - Represents a "stand-alone" WHERE clause
 
+=head1 VERSION
+
+version 0.35
+
 =head1 SYNOPSIS
 
   my $sql = Fey::SQL->new( dbh => $dbh );
@@ -64,19 +72,24 @@ Parameters> for more details.
 
 This class does C<Fey::Role::SQL::HasWhereClause> role.
 
-=head1 AUTHOR
-
-Dave Rolsky, <autarch@urth.org>
-
 =head1 BUGS
 
 See L<Fey> for details on how to report bugs.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
+  Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
