@@ -1,13 +1,15 @@
 package Fey::Table::Alias;
+BEGIN {
+  $Fey::Table::Alias::VERSION = '0.35';
+}
 
 use strict;
 use warnings;
-
-our $VERSION = '0.34';
+use namespace::autoclean;
 
 use Fey::Exceptions qw(param_error);
 use Fey::Table;
-use Fey::Types;
+use Fey::Types qw( Column HashRef Str Table );
 
 use Moose;
 use MooseX::Params::Validate qw( pos_validated_list );
@@ -16,43 +18,43 @@ use MooseX::StrictConstructor;
 
 with 'Fey::Role::TableLike';
 
-has 'id' =>
-    ( is         => 'ro',
-      lazy_build => 1,
-      init_arg   => undef,
-    );
+has 'id' => (
+    is         => 'ro',
+    lazy_build => 1,
+    init_arg   => undef,
+);
 
-has 'table' =>
-    ( is      => 'ro',
-      isa     => 'Fey::Table',
-      handles => [ 'schema', 'name' ],
-    );
+has 'table' => (
+    is      => 'ro',
+    isa     => Table,
+    handles => [ 'schema', 'name' ],
+);
 
-has 'alias_name' =>
-    ( is         => 'ro',
-      isa        => 'Str',
-      lazy_build => 1,
-    );
+has 'alias_name' => (
+    is         => 'ro',
+    isa        => Str,
+    lazy_build => 1,
+);
 
-has '_columns' =>
-    ( traits   => [ 'Hash' ],
-      is       => 'bare',
-      isa      => 'HashRef[Fey::Column]',
-      default  => sub { {} },
-      handles  => { _get_column => 'get',
-                    _set_column => 'set',
-                    _has_column => 'exists',
-                  },
-      init_arg => undef,
-    );
+has '_columns' => (
+    traits  => ['Hash'],
+    is      => 'bare',
+    isa     => HashRef[Column],
+    default => sub { {} },
+    handles => {
+        _get_column => 'get',
+        _set_column => 'set',
+        _has_column => 'exists',
+    },
+    init_arg => undef,
+);
 
 with 'Fey::Role::Named';
 
-
 {
     my %Numbers;
-    sub _build_alias_name
-    {
+
+    sub _build_alias_name {
         my $self = shift;
 
         my $name = $self->name();
@@ -62,8 +64,7 @@ with 'Fey::Role::Named';
     }
 }
 
-sub column
-{
+sub column {
     my $self = shift;
     my ($name) = pos_validated_list( \@_, { isa => 'Str' } );
 
@@ -81,8 +82,7 @@ sub column
     return $clone;
 }
 
-sub columns
-{
+sub columns {
     my $self = shift;
 
     my @cols = @_ ? @_ : map { $_->name() } $self->table()->columns();
@@ -92,36 +92,41 @@ sub columns
 
 # Making this an attribute would be a hassle since we'd need to reset
 # it whenever the associated table's keys changed.
-sub primary_key
-{
-    return [ $_[0]->columns( map { $_->name() } @{ $_[0]->table()->primary_key() } ) ];
+sub primary_key {
+    return [
+        $_[0]->columns(
+            map { $_->name() } @{ $_[0]->table()->primary_key() }
+        )
+    ];
 }
 
-sub is_alias { 1 }
+sub is_alias {1}
 
-sub sql_with_alias
-{
-    return
-        (   $_[1]->quote_identifier( $_[0]->table()->name() )
-          . ' AS '
-          . $_[1]->quote_identifier( $_[0]->alias_name() )
-        );
+sub sql_with_alias {
+    return (  $_[1]->quote_identifier( $_[0]->table()->name() ) . ' AS '
+            . $_[1]->quote_identifier( $_[0]->alias_name() ) );
 }
 
 sub _build_id { $_[0]->alias_name() }
 
-no Moose;
-
 __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: Represents an alias for a table
+
+
+
+=pod
 
 =head1 NAME
 
 Fey::Table::Alias - Represents an alias for a table
 
+=head1 VERSION
+
+version 0.35
+
 =head1 SYNOPSIS
 
   my $alias = $user_table->alias();
@@ -200,19 +205,24 @@ Returns a unique string identifying the alias.
 This class does the L<Fey::Role::TableLike> and L<Fey::Role::Named>
 roles.
 
-=head1 AUTHOR
-
-Dave Rolsky, <autarch@urth.org>
-
 =head1 BUGS
 
 See L<Fey> for details on how to report bugs.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
+  Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
